@@ -1,3 +1,3 @@
 from shopify.version import VERSION
-from shopify.session import Session, ValidationException
+from shopify.session import Session
 from shopify.resources import *
