@@ -18,4 +18,4 @@ class Order(ShopifyResource, mixins.Metafields, mixins.Events):
         return Transaction.find(order_id=self.id)
 
     def capture(self, amount=""):
-        return Transaction.create(amount=amount, kind="capture", order_id=self.id)
+        return Transaction.create({"amount": amount, "kind": "capture", "order_id": self.id})
